pub fn trees_equal(a: &SyntaxNode, b: &SyntaxNode) -> boolExpand description
Returns true if both trees emit the same string (same tokens and trivia).
pub fn trees_equal(a: &SyntaxNode, b: &SyntaxNode) -> boolReturns true if both trees emit the same string (same tokens and trivia).