pub fn trees_equal_semantic(a: &SyntaxNode, b: &SyntaxNode) -> boolExpand description
Returns true if both trees have the same semantic content (ignoring trivia).
pub fn trees_equal_semantic(a: &SyntaxNode, b: &SyntaxNode) -> boolReturns true if both trees have the same semantic content (ignoring trivia).